use crate::feature::role::Role;

use super::DATABASE_CONNECTIONS;

pub async fn create(name: &String) -> Result<Role, sqlx::Error> {
    sqlx::query_as!(
        Role,
        r#"
            INSERT INTO "role"(name)
            VALUES ($1)
            RETURNING *
        "#,
        name,
    )
    .fetch_one(&*DATABASE_CONNECTIONS)
    .await
}

pub async fn read(id: &i64) -> Result<Role, sqlx::Error> {
    sqlx::query_as!(
        Role,
        r#"
            SELECT * FROM "role" WHERE "id" = $1
        "#,
        id
    )
    .fetch_one(&*DATABASE_CONNECTIONS)
    .await
}

pub async fn update(id: &i64, name: &String) -> Result<Role, sqlx::Error> {
    sqlx::query_as!(
        Role,
        r#"
        UPDATE "role" SET "name" = $2 WHERE "id" = $1
        RETURNING *
    "#,
        id,
        name,
    )
    .fetch_one(&*DATABASE_CONNECTIONS)
    .await
}

pub async fn delete(id: &i64) -> Result<Role, sqlx::Error> {
    sqlx::query_as!(
        Role,
        r#"
        DELETE FROM "role" WHERE "id" = $1
        RETURNING *
    "#,
        id
    )
    .fetch_one(&*DATABASE_CONNECTIONS)
    .await
}

pub async fn read_all() -> Result<Vec<Role>, sqlx::Error> {
    sqlx::query_as!(
        Role,
        r#"
            SELECT * FROM "role"
        "#,
    )
    .fetch_all(&*DATABASE_CONNECTIONS)
    .await
}
